##PROCEDURE(help) ResChain[ArrayAddIfNotIn]
##HALFLINE This procedure appends an element to an Array if it is not already a member of it.
##AUTHOR AmirHosein Sadeghimanesh
##DATE November 2021
##CALLINGSEQUENCE
##- ArrayAddIfNotIn( 'A', 'a' )
##PARAMETERS
##- 'A'                  : An Array.
##- 'a'                  : anything.
##RETURNS
##- It modifies 'A' directly, so it returns nothing. To see the changes, call 'A'. If 'a' is already a member of 'A', 'A' should not have been changed, otherwise, 'a' should be added at the end of 'A'.
##DESCRIPTION
##- Maple\'s 'ArrayTools:-Append' appends an element at the end of an Array without checking if it is already a member or not. Since 'MutableSet' has some properties that we are not interested in for the procedures in this package, we keep using Arrays, but we still need to check the membership before appending. This proc is just to reduce the repeatition of a few lines of codes.
##EXAMPLES
##> with(ResChain): # ArrayAddIfNotIn is a local proc in ResChain by default.
##> A := Array([5, 2, 8]):
##> ArrayAddIfNotIn( A, 5 ):
##> A;
##- Vector[row](3, [5, 2, 8])
##> ArrayAddIfNotIn( A, 14 )
##> A;
##- Vector[row](4, [5, 2, 8, 14])
##SEEALSO
##- ArrayTools:-Append
##XERFMAP
##- 

ArrayAddIfNotIn := proc(A :: Array, a)

    description "Appends an element to an Array if it is not already a member of the Array.";

	if not a in A then
		ArrayTools:-Append(A, a):
	end if:

end proc: